@@ -35,13 +35,14 @@ def abs_file():
     return traceback.extract_stack()[-2].filename
 
 
-def abs_file_base(path=''):
+def abs_file_base(file, path=''):
     """
     获取当前【调用此函数的文件的上级目录】为基准开始的某个路径的绝对路径
+    :param file :请传入 __file__
     :param path: 上级目录下的文件路径位置
     :return:
     """
-    db_path = os.path.dirname(os.path.abspath(abs_file()))
+    db_path = os.path.dirname(os.path.abspath(file))
     return os.path.join(db_path, path)
 
 
@@ -126,4 +127,3 @@ def gain_path_files(_path):
     files = list(list(os.walk(_path))[0])[2]
 
     return files
-
